@@ -7,7 +7,7 @@ use warnings;
 
 =head1 NAME
 
-Biber::Entries - Biber::Entries objects
+Biber::Entries
 
 =head2 new
 
@@ -119,6 +119,7 @@ __END__
 
 =head1 AUTHORS
 
+François Charette, C<< <firmicus at ankabut.net> >>
 Philip Kime C<< <philip at kime.org.uk> >>
 
 =head1 BUGS
@@ -128,8 +129,7 @@ L<https://github.com/plk/biber/issues>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2012 François Charette and Philip Kime, all rights reserved.
-Copyright 2012-2024 Philip Kime, all rights reserved.
+Copyright 2009-2017 François Charette and Philip Kime, all rights reserved.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
